==> dojo-1.9.4.tgz: package/cldr/nls/th/roc.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"field-dayperiod": "ช่วงวัน",
	"field-minute": "นาที",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-day-relative+-1": "เมื่อวาน",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-day-relative+-2": "เมื่อวานซืน",
	"field-weekday": "วันในสัปดาห์",
	"dateFormatItem-MMM": "LLL",
	"field-era": "สมัย",
	"dateFormatItem-Gy": "ปีGที่ y",
	"field-hour": "ชั่วโมง",
	"dateFormatItem-y": "ปีGที่ y",
	"dateFormatItem-yyyy": "ปีGที่ y",
	"dateFormatItem-Ed": "E d",
	"field-day-relative+0": "วันนี้",
	"field-day-relative+1": "พรุ่งนี้",
	"eraAbbr": [
		"ปีก่อนไต้หวัน",
		"ไต้หวัน"
	],
	"field-day-relative+2": "มะรืนนี้",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"dateFormat-long": "d MMMM ปีG y",
	"field-zone": "เขต",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"dateFormat-medium": "d MMM G y",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-year-relative+0": "ปีนี้",
	"field-year-relative+1": "ปีหน้า",
	"field-year-relative+-1": "ปีที่แล้ว",
	"dateFormatItem-ms": "mm:ss",
	"field-year": "ปี",
	"field-week": "สัปดาห์",
	"dateFormatItem-yyyyMd": "d/M/GGGGG y",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"dateFormatItem-yyyyMEd": "E d/M/GGGGG y",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-week-relative+1": "สัปดาห์หน้า",
	"field-month-relative+0": "เดือนนี้",
	"dateFormatItem-H": "HH",
	"field-month": "เดือน",
	"field-month-relative+1": "เดือนหน้า",
	"dateFormatItem-M": "L",
	"field-second": "วินาที",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-day": "วัน",
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"dateFormatItem-MEd": "E, d/M",
	"dateFormatItem-hm": "h:mm a",
	"dateFormat-short": "d/M/yy",
	"dateFormatItem-yyyyM": "M/GGGGG y",
	"dateFormat-full": "EEEEที่ d MMMM ปีGที่ y",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yyyyMMM": "MMM G y",
	"dateFormatItem-d": "d",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"dateFormatItem-h": "h a"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/th/roc.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "ขณะนี้",
	"field-weekday": "วันในสัปดาห์",
	"field-wed-relative+0": "พุธนี้",
	"field-wed-relative+1": "พุธหน้า",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-tue-relative+-1": "อังคารที่แล้ว",
	"dateFormat-long": "d MMMM ปีG y",
	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
	"field-wed-relative+-1": "พุธที่แล้ว",
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"dateFormat-full": "EEEEที่ d MMMM ปีGที่ y",
	"dateFormatItem-yyyyMEd": "E d/M/GGGGG y",
	"field-thu-relative+-1": "พฤหัสที่แล้ว",
	"dateFormatItem-Md": "d/M",
	"field-era": "สมัย",
	"field-year": "ปี",
	"field-hour": "ชั่วโมง",
	"field-sat-relative+0": "เสาร์นี้",
	"field-sat-relative+1": "เสาร์หน้า",
	"field-day-relative+0": "วันนี้",
	"field-thu-relative+0": "พฤหัสนี้",
	"field-day-relative+1": "พรุ่งนี้",
	"field-thu-relative+1": "พฤหัสหน้า",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"field-day-relative+2": "มะรืนนี้",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "ปีGที่ y",
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM G y",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"field-sun-relative+0": "อาทิตย์นี้",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "อาทิตย์หน้า",
	"eraAbbr": [
		"ปีก่อนไต้หวัน",
		"ไต้หวัน"
	],
	"field-minute": "นาที",
	"field-dayperiod": "ช่วงวัน",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "เมื่อวาน",
	"dateFormatItem-h": "h a",
	"field-day-relative+-2": "เมื่อวานซืน",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-fri-relative+0": "ศุกร์นี้",
	"field-fri-relative+1": "ศุกร์หน้า",
	"field-day": "วัน",
	"field-zone": "เขตเวลา",
	"dateFormatItem-y": "ปีGที่ y",
	"field-year-relative+-1": "ปีที่แล้ว",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "d/M/GGGGG y",
	"field-month": "เดือน",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "อังคารนี้",
	"field-tue-relative+1": "อังคารหน้า",
	"field-mon-relative+0": "จันทร์นี้",
	"field-mon-relative+1": "จันทร์หน้า",
	"dateFormat-short": "d/M/y G",
	"field-second": "วินาที",
	"field-sat-relative+-1": "เสาร์ที่แล้ว",
	"field-sun-relative+-1": "อาทิตย์ที่แล้ว",
	"field-month-relative+0": "เดือนนี้",
	"field-month-relative+1": "เดือนหน้า",
	"dateFormatItem-Ed": "E d",
	"field-week": "สัปดาห์",
	"dateFormat-medium": "d MMM G y",
	"field-year-relative+0": "ปีนี้",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"dateFormatItem-yyyyM": "M/GGGGG y",
	"field-year-relative+1": "ปีหน้า",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-mon-relative+-1": "จันทร์ที่แล้ว",
	"dateFormatItem-yyyy": "ปีGที่ y",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-week-relative+1": "สัปดาห์หน้า"
}
//end v1.x content
);
